require "dot_env/version"
require 'logger'
require_relative 'dot_env/parser'
require_relative 'dot_env/environment'

module DotEnv
  @parser    = DotEnv::Parser
  @env       = DotEnv::Environment.new(@parser, ARGV)
  @env_file  = @env.fetch('ENVIRONMENT_SETTINGS_FILE', '.env')

  def self.read_env_file(filepath)
    File.open(filepath).each do |line|
      unless line.strip.empty? or line.strip.start_with?('#')
        key, value = @parser.get_value_pair(line.strip)
        @env.set(key, value)
      end
    end.close()
  end

  def self.set_default_env(filepath)
    current_env = @env.get_current
    @env.set_current(current_env)
  end

  def self.set_environment(filepath)
    self.read_env_file(filepath)
    current_env = @env.get_current
  rescue Errno::ENOENT
    self.set_default_env(filepath)
  end

  def self.get_environment(filepath=nil)
    filepath ||= @env_file
    self.set_environment(filepath)
    @env.get_current
  end
end
