module DotEnv
  class Environment
    attr_accessor :cmdline_args,
                  :test_runner_words,
                  :test_file_words

    def initialize(parser, command_line_args)
      @parser = parser
      @cmdline_args = command_line_args
      @test_runner_words = ['spec', 'rspec', 'cucumber']
      @test_file_words = ['test', 'spec', 'feature']
    end

    def fetch(key, default=nil)
      value = ENV.fetch(key, default)
      value = @parser.parse(value) unless value.nil?
    end

    def set(key, value)
      ENV[key] = value
    end

    def check_test_runner
      @test_runner_words.each do |word|
        return 'testing' if @cmdline_args.include? word
      end

      nil
    end

    def check_test_file(argword)
      @test_file_words.each do |word|
        return 'testing' if argword.include? word
      end

      nil
    end

    def check_if_testing
      test_runner = check_test_runner
      test_file = nil
      @cmdline_args.each { |a| test_file = check_test_file(a) if test_file.nil? }
      current_env = test_runner || test_file
    end

    def set_current(env)
      set('APP_ENV', env)
    end

    def get_current
      check_if_testing || fetch('APP_ENV', 'development')
    end
  end
end
