module DotEnv
  module Parser
    TRUEWORDS = ['true', 'yes', '1']
    FALSEWORDS = ['false', 'no', '0']

    def self.get_value_pair(line)
      key, value = line.chomp.split('=').each {|v| v.gsub!(/['"]/, '') }.each(&:strip!)
      value = self.expand(value)
      [key, value]
    end

    def self.cleanup(value)
      value.gsub(/["'\[\]]/, '').split(',').each(&:strip!)
    end

    def self.expand(value)
      value.gsub!(/\$\{?(\w+)\}?/) { ENV.fetch($1, nil) } || value
    end

    def self.check_truthy(value)
      if TRUEWORDS.include? value.to_s.downcase
        return true
      else
        return value
      end
    end

    def self.check_falsy(value)
      if FALSEWORDS.include? value.to_s.downcase
        return false
      else
        return value
      end
    end

    def self.parse(value)
      parsed = []
      self.cleanup(value).each do |v|
        v = self.expand(v)
        v = self.check_truthy(v)
        v = self.check_falsy(v)
        parsed.push v
      end

      parsed.length > 1 ? parsed : parsed.first
    end
  end
end
